<template>
  <nut-radio-group v-model="model" direction="horizontal">
    <nut-radio
      v-for="item in optionsWithAll"
      :key="item.value"
      :label="item.value"
      :value="item.value"
      shape="button"
      >{{ item.text }}</nut-radio
    >
  </nut-radio-group>
</template>

<script setup lang="ts">
import { computed } from 'vue';
import { convertOptions, ValueEnum } from 'senin-mini/utils';

defineOptions({
  name: 'ProRadio',
});

type Props = {
  showAllBtn?: boolean;
  allBtnLabel?: string;
  allBtnValue?: string | number | null;
  enumLabelKey?: string;
  enumValueKey?: string;
  valueEnum?: ValueEnum;
};

const props = withDefaults(defineProps<Props>(), {
  allBtnLabel: '不限',
  allBtnValue: '',
  enumLabelKey: 'name',
  enumValueKey: 'id',
});

const model = defineModel<string | number>();

const options = computed(() =>
  convertOptions(props.valueEnum, props.enumLabelKey, props.enumValueKey)
);

const optionsWithAll = computed(() => {
  if (props.showAllBtn) {
    return [{ text: props.allBtnLabel, value: props.allBtnValue }, ...options.value];
  }
  return options.value;
});
</script>

<style lang="scss">
@import '@/styles/common.scss';
</style>
